@@ -1,6 +1,9 @@
 plot.diversityMatrix <- function(x, num.cluster=2, col.area = "gray",
-                     col.medoids = "blue", ...)
+                     col.medoids = "blue", type="mds", 
+                     show.cluster.center=TRUE,...)
 {
+  if (type=="mds") {
+  
   distmat <- x
   
   result <- cluster::pam(dist(distmat), num.cluster, TRUE, "euclidean")
@@ -20,6 +23,7 @@ plot.diversityMatrix <- function(x, num.cluster=2, col.area = "gray",
     col.medoids <- rep(col.medoids, num.cluster)
   }
   
+  # draw convex hulls
   for (cn in unique(result$clustering)) {
     rng <- which(result$clustering == cn)
     idx <- grDevices::chull(x[rng], y[rng])
@@ -28,14 +32,37 @@ plot.diversityMatrix <- function(x, num.cluster=2, col.area = "gray",
                                                                            cn)])
   }
   
-  for (i in 1:length(result$medoids)) {
-    rad <- (max(x)-min(x))/20
-    plotrix::draw.circle(x[result$medoids][i], 
+  # draw cluster IDs
+  text(x,y,labels=1:nrow(distmat))
+  
+  # draw cluster centers
+  if (show.cluster.center) {
+    for (i in 1:length(result$medoids)) {
+      rad <- (max(x)-min(x))/20
+      plotrix::draw.circle(x[result$medoids][i], 
                          y[result$medoids][i],radius=rad,col=col.medoids[i])
+      text(x[result$medoids][i], 
+           y[result$medoids][i], labels = i)
+    }
   }
   
   
   #points(x[result$medoids], y[result$medoids],pch="o",col="green")
-  text(x,y,labels=1:nrow(distmat))
+
   
-}
\ No newline at end of file
+  } else if (type=="hist") {
+     xlab="Diversity"
+     main="Forest diversities"
+     values <- x[lower.tri(x)]
+    hist(x,main=main,xlab=xlab,...)
+  } else {
+    stop("Type not supported!")
+  }
+  
+}
+
+
+#plot.diversityMatrix <- function(x, xlab="Diversity", main="Forest diversities", ...) {
+#  values <- x[lower.tri(x)]
+#  hist(x,main=main,xlab=xlab,...)
+#}
